import * as cdeops from 'cdeops/client';
/** The plain properties of a {@link module:sourcegraph.WorkspaceRoot}, without methods and accessors. */
export interface WorkspaceRoot {
    uri: string;
}
/** The plain properties of a {@link module:sourcegraph.Position}, without methods and accessors. */
export interface Position {
    /** Zero-based line number. */
    readonly line: number;
    /** Zero-based character on a line. */
    readonly character: number;
}
/** The plain properties of a {@link module:sourcegraph.Range}, without methods and accessors. */
export interface Range {
    /**
     * The start position. It is before or equal to [end](#Range.end).
     */
    readonly start: Position;
    /**
     * The end position. It is after or equal to [start](#Range.start).
     */
    readonly end: Position;
}
/** The plain properties of a {@link module:sourcegraph.Selection}, without methods and accessors. */
export interface Selection extends Range {
    /**
     * The position at which the selection starts. This position might be before or after {@link Selection#active}.
     */
    readonly anchor: Position;
    /**
     * The position of the cursor. This position might be before or after {@link Selection#anchor}.
     */
    readonly active: Position;
    /**
     * Whether the selection is reversed. The selection is reversed if {@link Selection#active} is before
     * {@link Selection#anchor}.
     */
    readonly isReversed: boolean;
}
/**
 * A location refers to a document (or a range within a document).
 *
 * @see module:cdeops.Location
 */ export interface Location {
    /** The URI of the document. */
    readonly uri: string;
    /** An optional range within the document. */
    readonly range?: Range;
}
/** The plain properties of a {@link module:sourcegraph.Definition}, without methods and accessors. */
export type Definition = Location | Location[] | null;
/**
 * A hover message.
 *
 * @see module:sourcegraph.Hover
 */ export interface Hover extends Pick<cdeops.Hover, 'contents' | 'alerts'> {
    /** The range that the hover applies to. */
    range?: Range;
}
/**
 * A decoration to apply to a text document.
 *
 * @see module:sourcgraph.TextDocumentDecoration
 */
export interface TextDocumentDecoration extends Pick<cdeops.TextDocumentDecoration, Exclude<keyof cdeops.TextDocumentDecoration, 'range'>> {
    /** The range that the decoration applies to. */
    range: Range;
}
