import { IRPCProtocol, ProxyIdentifier } from './proxy-identifier';
import { IOrganizationData, IConfigurationInitData, IDocumentsShape } from './common.protocol';
import { CdmLogger } from '@cdm-logger/core';
import { IDisposable } from '@vscode-alt/monaco-editor/esm/vs/base/common/lifecycle';
import { ExtensionIdentifier, ICommandHandlerDescription, IExtensionDescription } from '@workbench-stack/core';
import { ConfigurationTarget, IConfigurationOverrides } from 'common';
import { IConfigurationChange } from '@adminide-stack/core';
import { UriComponents } from '@vscode-alt/monaco-editor/esm/vs/base/common/uri';
import { CancellationToken } from '@vscode-alt/monaco-editor/esm/vs/base/common/cancellation';
import Severity from '@vscode-alt/monaco-editor/esm/vs/base/common/severity';
import { SerializedError } from '@vscode-alt/monaco-editor/esm/vs/base/common/errors';
export interface IInitData {
    version: string;
}
export interface IExtHostContext extends IRPCProtocol {
    getUIProxy?<T>(identifier: ProxyIdentifier<T>): T;
}
export interface ExtHostCommandsShape {
    $executeContributedCommand<T>(id: string, ...args: any[]): Promise<T>;
    $getContributedCommandHandlerDescriptions(): Promise<{
        [id: string]: string | ICommandHandlerDescription;
    }>;
}
export interface ExtHostConfigurationShape {
    $initializeConfiguration(data: IConfigurationInitData): void;
    $acceptConfigurationChanged(data: IConfigurationInitData, change: IConfigurationChange): void;
}
export interface ExtHostOrganizationShape {
    $acceptOrganizationData(organization: IOrganizationData): void;
}
export interface MainThreadDocumentsShape extends IDocumentsShape, IDisposable {
}
export interface ExtHostLogServiceShape {
    $setLevel(level: CdmLogger.LoggerLevel): void;
}
export interface ExtHostExtensionServiceShape {
    $startExtensionHost(enabledExtensionIds: ExtensionIdentifier[]): Promise<void>;
    $activateByEvent(activationEvent: string): Promise<void>;
    $activate(extensionId: ExtensionIdentifier, activationEvent: string): Promise<void>;
    $deltaExtensions(toAdd: IExtensionDescription[], toRemove: ExtensionIdentifier[]): Promise<void>;
    $test_latency(n: number): Promise<number>;
    $test_up(b: Buffer): Promise<number>;
    $test_down(size: number): Promise<Buffer>;
}
export interface IMainContext extends IRPCProtocol {
}
export interface MainThreadCommandsShape extends IDisposable {
    $registerCommand(id: string): void;
    $unregisterCommand(id: string): void;
    $executeCommand<T>(id: string, args: any[]): Promise<T>;
    $getCommands(): Promise<string[]>;
}
export interface MainThreadConfigurationShape extends IDisposable {
    $updateConfigurationOption(target: ConfigurationTarget, key: string, value: any, overrides: IConfigurationOverrides | undefined): Promise<void>;
    $removeConfigurationOption(target: ConfigurationTarget, key: string, overrides: IConfigurationOverrides | undefined): Promise<void>;
}
export interface MainThreadUrlsShape extends IDisposable {
    $registerUriHandler(handle: number, extensionId: ExtensionIdentifier): Promise<void>;
    $unregisterUriHandler(handle: number): Promise<void>;
}
export interface MainThreadOrganizationShape extends IDisposable {
    $checkExists(includes: string[], token: CancellationToken): Promise<boolean>;
    $saveAll(includeUntitled?: boolean): Promise<boolean>;
    $updateOrganizationResources(extensionName: string, index: number, deleteCount: number, organizationResourcesToAdd: {
        uri: UriComponents;
        name?: string;
    }[]): Promise<void>;
    $resolveProxy(url: string): Promise<string>;
}
export interface MainThreadExtensionServiceShape extends IDisposable {
    $localShowMessage(severity: Severity, msg: string): void;
    $onWillActivateExtension(extensionId: ExtensionIdentifier): void;
    $onDidActivateExtension(extensionId: ExtensionIdentifier, startup: boolean, codeLoadingTime: number, activateCallTime: number, activateResolvedTime: number, activationEvent: string): void;
    $onExtensionActivationFailed(extensionId: ExtensionIdentifier): void;
    $onExtensionRuntimeError(extensionId: ExtensionIdentifier, error: SerializedError): void;
    $addMessage(extensionId: ExtensionIdentifier, severity: Severity, message: string): void;
}
export declare const MainContext: {
    MainThreadCommands: ProxyIdentifier<MainThreadCommandsShape>;
    MainThreadConfiguration: ProxyIdentifier<MainThreadConfigurationShape>;
    MainThreadUrls: ProxyIdentifier<MainThreadUrlsShape>;
    MainThreadOrganization: ProxyIdentifier<MainThreadOrganizationShape>;
    MainThreadExtensionService: ProxyIdentifier<MainThreadExtensionServiceShape>;
};
export declare const ExtHostContext: {
    ExtHostCommands: ProxyIdentifier<ExtHostCommandsShape>;
    ExtHostConfiguration: ProxyIdentifier<ExtHostConfigurationShape>;
    ExtHostExtensionService: ProxyIdentifier<ExtHostExtensionServiceShape>;
    ExtHostLogService: ProxyIdentifier<ExtHostLogServiceShape>;
    ExtHostOrganization: ProxyIdentifier<ExtHostOrganizationShape>;
};
